@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20210930';
+our $VERSION = '0.20211029';
 
-# Table last modified: 2021-09-30
+# Table last modified: 2021-10-29
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -103,11 +103,11 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9]|6[0-257-9])|1(?:1[0137-9]|0[1-589]|7[12468]|8[124-9]|2[013-8]|4[014]|5[0-248]|6[05689]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|2[0147]|3[09]|[48][48])|0(?:19|66|8[06]|5[015]|7[07-9])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9]|6[0-257-9])|1(?:1[0137-9]|0[1-589]|7[12468]|8[124-9]|2[013-8]|4[014]|5[0-248]|6[05689]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|2[0147]|3[09]|[48][48])|0(?:19|8[06]|5[015]|7[07-9]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-35689])|3(?:6[2356]|4[5-7]|0[12578]|7[0-258]|8[1358]|5[0-689]|2[13-8]|3[013568]|1[013-7])|6(?:8[28]|6[2578]|1[0-25-79]|3[01346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[04-68]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-79])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:0[2359]|4[19]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|7[0237]|5[0367])|0(?:30|2[24-6]|7[78]|8[0-358]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|7[03568]|4[013578])|3(?:7[03]|1[1378]|5[0-2458]|2[1348]|0[136-8]|8[0348]|4[15-7]|6[036]|3[01357-9])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[067]|6[068]|8[0469]|3[1269])|0[01]1)|6060))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|1[014-8]|8[1389]|4[25]|3[0-589]|5[18]|7[014-9])|3(?:7[027-9]|1[0-3579]|2[458]|8[013689]|6[05]|5[0167]|0[1-7]|3[02358]|4[0-5])|5(?:72|1[028]|3[035689]|8[01458]|4[3-8]|5[014-689]|2[0136-8]|6[06-8]|0[1256])|4(?:70|3[013589]|5[056]|0[124-8]|8[168]|4[02-489]|2[0-469]|6[08]|1[05689])|2(?:40|71|1[0-258]|3[38]|0[568]|8[0-589]|5[0-24-8]|6[026])|6(?:14|5[06]|6[0158]|8[05]|7[08])|0(?:55|77|0[1-47]|1[01]))|6241))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|1[014-8]|8[1389]|4[25]|3[0-589]|5[18]|7[014-9])|3(?:7[027-9]|1[0-3579]|2[458]|8[013689]|6[05]|5[0167]|0[1-7]|3[02358]|4[0-5])|5(?:72|1[028]|3[035689]|8[01458]|4[3-8]|5[014-689]|2[0136-8]|6[06-8]|0[1256])|4(?:70|3[013589]|5[056]|1[035689]|0[124-8]|8[168]|4[02-489]|2[0-469]|6[08])|2(?:40|71|1[0-258]|3[38]|0[568]|8[0-589]|5[0-24-8]|6[026])|6(?:14|5[06]|6[0158]|8[05]|7[08])|0(?:55|77|0[1-47]|1[01]))|6241))',
     '105' => '(?:(?:8(?:4(?:8[2-6]|5[1-36-8]|6[014-689]|7[0-357]|3[1-7]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|5[013-8]|1[0-25-8]|8[0-589]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:3[04]|6[0568]|8[015689]|2[01356]|5[468]|1[013-57]|4[024]|7[06-8]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:[12]0|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|7[136-8]|3[17]|1[458]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|0[18]|2[0256]|3[069])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|5(?:32|81|1[14]|0[2578]|7[27]|2[0178]|6[037]|5[0268]|4[56])|6(?:50|8[06]|0[14]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|3(?:55|60|4[0289]|7[013]|2[0346]|8[048]|3[026])|0(?:[16]0|77|0[16])|797))',
@@ -226,7 +226,7 @@ our %ZIP_TABLE = (
     '244' => '(?:8(?:5(?:0[1-3]|7[17]|2[28]|5[058]|8[589]|6[679]|1[01]|3[039])|601))',
     '245' => '(?:85(?:[16]0|42|89|5[058]|7[57]))',
     '246' => '(?:85(?:20|5[06]))',
-    '247' => '(?:8(?:5(?:[15]0|7[07]|8[58]|3[038])|6(?:30|86)|730))',
+    '247' => '(?:8(?:5(?:[156]0|8[58]|7[078]|3[038])|6(?:[13]0|86)|730))',
     '248' => '(?:8(?:55[58]|686))',
     '249' => '(?:8(?:510|686))',
     '250' => '(?:(?:0(?:2(?:80|9[2-68])|19[23]|39[28]|493|592)|85(?:11|55|60|88)))',
@@ -393,7 +393,7 @@ our %ZIP_TABLE = (
     '417' => '(?:8(?:5(?:6[05-7]|3[01358]|8[058]|0[135-8]|1[0-29]|5[05]|7[0157]|2[029]|4[035])|6(?:[15]0|32|86|0[19])))',
     '418' => '(?:(?:86(?:[68]6|01)|0192))',
     '419' => '(?:0(?:19[23]|29[35]|392))',
-    '420' => '(?:8(?:6(?:6[06]|2[02-48]|4[14]|0[1-468]|8[0158]|7[07]|3[03679]|5[05]|1[0-268])|5(?:70|1[0-257]|0[1-357-9]|8[0158]|6[07]|5[0578]|2[0-3578]|3[06-8])|7(?:47|0[3469]|[12][02]|3[389]|6[01])))',
+    '420' => '(?:8(?:6(?:6[06]|2[02-48]|4[14]|0[1-468]|8[0158]|7[07]|3[03679]|5[05]|1[0-268])|5(?:70|1[0-257]|0[1-357-9]|8[0158]|6[07]|5[0578]|2[0-3578]|3[06-8])|7(?:0[3469]|[12][02]|3[389]|6[01])))',
     '421' => '(?:(?:0(?:1(?:88|9[23578])|39[2-7]|59[23568]|49[2356]|29[238])|3(?:29[25-7]|392)|1(?:29[58]|392)))',
     '422' => '(?:8(?:5(?:45|50|8[015]|[26]\d|0[24-79]|7[013-68]|3[01]|1[0-24-9])|6(?:5[04]|3[03]|7[07]|8[068]|6[68]|1[059]|2[0-28])|7(?:66|87)))',
     '424' => '(?:(?:8(?:6(?:48|50|0[1-3]|7[78]|3[1367]|[68][68]|1[01]|2[024])|7(?:82|3[04]|2[0147]|5[0-25]|6[07]|0[18]|1[579])|5(?:66|0[23]|5[058]|1[01]))|0(?:19[23]|292)))',
@@ -666,7 +666,7 @@ our %ZIP_TABLE = (
     '703' => '(?:8(?:5(?:20|44|6[06]|3[03]|8[0568]|0[1258]|5[058]|7[03-5]|1[016])|6(?:55|86)|750))',
     '704' => '(?:85(?:10|55|88|0[12]))',
     '705' => '(?:8(?:5(?:10|0[127]|[58][58]|7[57])|6(?:0[23]|1[45])))',
-    '706' => '(?:8(?:5(?:01|55|3[13]|1[01])|65[15]))',
+    '706' => '(?:8(?:5(?:01|55|88|3[13]|1[01])|65[15]))',
     '707' => '(?:85(?:85|0[12]))',
     '708' => '(?:(?:8(?:5(?:20|1[0-25-9]|0[1-35-79])|6(?:09|5[2-47]))|1(?:19[38]|39[23])|0(?:39[23]|698)))',
     '709' => '(?:(?:0(?:49[24-8]|89[2578]|792)|2(?:19[268]|39[38])|3(?:49[478]|198)|(?:12|4[23])92))',
@@ -837,7 +837,7 @@ our %ZIP_TABLE = (
     '876' => '(?:(?:8(?:5(?:55|8[05])|6(?:01|66))|2492))',
     '877' => '(?:(?:8(?:5(?:01|55)|6(?:01|86))|0(?:39[23]|296)|1292))',
     '878' => '(?:8555)',
-    '879' => '(?:(?:5(?:19[235-8]|59[235]|498)|4(?:49[28]|[26]92|194)|0(?:49[2358]|692)|(?:26|6[16])92|159[258]|719[28]))',
+    '879' => '(?:(?:5(?:19[235-8]|59[235]|498)|4(?:49[28]|[26]92|194)|0(?:49[2358]|692)|(?:26|6[16])92|159[2358]|719[28]))',
     '880' => '(?:(?:8(?:5(?:7[05-7]|4[3-6]|2[02357]|1[0-357-9]|8[01368]|3[02359]|0[1-357-9]|6[167]|5[015-9])|6(?:10|25|49|3[39]|0[124-6]|6[68])|725)|1(?:19[2356]|39[28])|029[3-578]|229[23]))',
     '881' => '(?:85(?:01|67))',
     '882' => '(?:(?:8(?:6(?:11|66|78|8[68])|5(?:85|0[38]))|1(?:29[3-5]|192)|0192))',
@@ -935,11 +935,11 @@ our %ZIP_TABLE = (
     '976' => '(?:85(?:01|10))',
     '979' => '(?:(?:0(?:19[25-8]|69[56])|2(?:39[2-4]|195|792)|1(?:[135]92|495)))',
     '980' => '(?:(?:8(?:4(?:7[78]|[04][1-35-8]|8[014-8]|2[0-369]|1[0145]|3[013569]|5[02-468]|6[016])|5(?:[15][015]|3[134]|4[3-6]|7\d|2[01569]|0[158]|6[0156]|8[013578])|6(?:40|86|5[0-26]|6[018]|0[1258]|3[1-36-9]|2[12]|7[017])|7(?:11|33|77|0[137]|9[2-578]))|6(?:0(?:55|88)|1(?:61|80))))',
-    '981' => '(?:(?:3(?:2(?:8[0178]|9[235-8])|6(?:8[0-24-68]|9[278])|1(?:9[2-5]|8[0589])|49[4-7]|[35]92)|85(?:33|85|6[03]|5[0-26-8]|0[25]|7[07]|2[235]|1[01]|4[035])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|0394|2192))',
+    '981' => '(?:(?:3(?:2(?:8[0178]|9[235-8])|6(?:8[0-24-68]|9[278])|1(?:9[2-5]|8[0589])|49[4-7]|[35]92)|85(?:10|33|85|6[03]|5[0-26-8]|0[25]|7[07]|2[235]|4[035])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|0394|2192))',
     '982' => '(?:8(?:5(?:31|44|66|77|2[13]|8[58]|5[15]|1[01]|0[125])|601|798))',
-    '983' => '(?:8(?:5(?:70|85|0[1247]|6[057]|3[367]|4[35]|2[023]|1[1-37]|5[1256])|6(?:01|22|39)))',
+    '983' => '(?:8(?:5(?:70|85|0[1247]|6[057]|3[367]|4[35]|2[023]|1[1-37]|5[1256])|6(?:01|22|39)|477))',
     '984' => '(?:8(?:5(?:0[135]|8[045]|7[057]|2[25]|6[0178]|3[0389]|1[0-2689]|5[0-3578]|4[035])|6(?:42|54|7[056]|0[13]|8[068]|6[689])))',
-    '985' => '(?:8(?:5(?:77|89|5[015]|2[12]|1[01]|0[12467]|3[13578])|6(?:55|0[17])))',
+    '985' => '(?:8(?:5(?:77|5[015]|2[12]|1[01]|0[12467]|3[13578])|6(?:55|0[17])))',
     '986' => '(?:(?:85(?:40|55|0[17]|2[25]|8[05])|0(?:195|792)|229[23]))',
     '987' => '(?:(?:2(?:29[23]|59[23]|195|392)|0(?:59[235]|19[25]|792)|860[23578]|139[35]))',
     '988' => '(?:(?:85(?:55|0[12])|039[23]))',
@@ -951,7 +951,7 @@ our %ZIP_TABLE = (
     '994' => '(?:8(?:5(?:01|85|1[01])|6[01]1))',
     '995' => '(?:8666)',
     '996' => '(?:8(?:501|602))',
-    '997' => '(?:(?:8(?:5(?:01|67|2[23]|[58][58]|1[15])|6(?:[01]1|55))|0(?:29[26]|[14]92)|1392))',
+    '997' => '(?:(?:8(?:5(?:01|67|2[23]|1[015]|[58][58])|6(?:[01]1|55))|0(?:29[26]|[14]92)|1392))',
     '998' => '(?:(?:8(?:5(?:[14]0|8[058]|5[05]|0[12])|6(?:11|33))|019[24]))',
     '999' => '(?:(?:3(?:79[25-7]|19[23]|292)|7(?:69[56]|292)|0(?:193|696)|[1458]292|229[23]))',
 );
